package App::Env::Scanner;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

App::Env::Scanner - Short module description

=head1 SYNOPSIS

use App::Env::Scanner;

=head1 DESCRIPTION

Extensive module description

=head1 BUGS

Current implementation is OS speciffic !!!

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# LIBRARY LOADING SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#-- Perl CPAN modules ---------------------------------------------------------#
use Sys::Hostname;

# Following module is optional, if the use fails, we do not care
eval "use Net::Address::IP::Local;";

#-- Custom application modules ------------------------------------------------#

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#
my %INFO = ();

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION);
    $VERSION 	= '0.1';
    $ENV{PATH} 	= '/bin:/usr/bin';
    $ENV{ENV} 	= undef;
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item os() [PUBLIC,STATIC]

  Usage     :
  Purpose   : Return the operating system name on the current host device
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub os
{
	my $class = shift;
	croak ((caller(0))[3] . ": class method invoked on object") if ref $class;
	unless (exists $INFO{'OS'})
	{
		my $os = `/bin/uname -s`;
		$os =~ s/^\s+//;
		$os =~ s/\s+$//;
		$INFO{'OS'} = $os;
	}
	return $INFO{'OS'};
}

=item os_ver() [PUBLIC,STATIC]

  Usage     :
  Purpose   : Return the operating system version on the current host device
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub os_ver
{
	my $class = shift;
	croak ((caller(0))[3] . ": class method invoked on object") if ref $class;
	unless (exists $INFO{'OS_VER'})
	{
		my $osver = `/bin/uname -r`;
		$osver =~ s/^\s+//;
		$osver =~ s/\s+$//;
		$INFO{'OS_VER'} = $osver;
	}
	return $INFO{'OS_VER'};
}

=item host_name() [PUBLIC,STATIC]

  Usage     :
  Purpose   : Return the current host device`s host name
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub host_name
{
	my $class = shift;
	croak ((caller(0))[3] . ": class method invoked on object") if ref $class;
	unless (exists $INFO{'HOSTNAME'})
	{
		$INFO{'HOSTNAME'} = hostname();
	}
	return $INFO{'HOSTNAME'};
}

=item ipv4() [PUBLIC,STATIC]

  Usage     :
  Purpose   : Return the current host device`s IPv4 address
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub ipv4
{
	my $class = shift;
	croak ((caller(0))[3] . ": class method invoked on object") if ref $class;
	unless (exists $INFO{'IPV4'})
	{
		$INFO{'IPV4'} = undef;
		eval { $INFO{'IPV4'} = Net::Address::IP::Local->public_ipv4(); };
	}
	return $INFO{'IPV4'};
}

=item ipv6() [PUBLIC,STATIC]

  Usage     :
  Purpose   : Return the current host device`s IPv6 address
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub ipv6
{
	my $class = shift;
	croak ((caller(0))[3] . ": class method invoked on object") if ref $class;
	unless (exists $INFO{'IPV6'})
	{
		$INFO{'IPV6'} = undef;
		eval { $INFO{'IPV6'} = Net::Address::IP::Local->public_ipv6(); };
	}
	return $INFO{'IPV6'};
}

=pod

=back

=cut

1;
