package Log::Filter::Message;
use strict;
use warnings;

use Data::Dumper;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Log::Filter::Message - Accepts messages containing certain PCRE patterns

=head1 SYNOPSIS

  use Log::Filter::Message;

  my $filter = new Log::Filter::Message('emerg.*127.0.0.1');
  my $filter = new Log::Filter::Message(['127.0.0.1','^notice'],'i r');

  my ($result, $continue) = $filter->accept($source, $severity, $message);

=head1 DESCRIPTION

This module accepts messages, whose MESSAGE body comply to the at least one of the given
PCRE patterns. Implementation is based on the Log::Filter::Re module, which
is able to aply the PCRE patterns to the $source and $severity as well.

=head1 USAGE

=head1 BUGS

=head1 SUPPORT

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Log::Filter::Re;

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION @ISA);
    $VERSION 	= '0.01';
    @ISA 		= ('Log::Filter::Re');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item _init() [PROTECTED]

  Usage     : Used from constructor as follows: return $self->_init(@_);
  Purpose   : Initialize newly created filter instance
  Returns   : $self
  Arguments : string $flags - (See Log::Filter::Re->_init() method for details on flags)
  Throws    : Croaks, if invoked on class
  Comments  : Internally used by parent`s new() method
  See Also  : Log::Filter::Re->_init() method

=cut

sub _init {
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	return $self->SUPER::_init('message', @_);
}

=pod

=back

=cut

1;
