package Log::Filter::Source;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Log::Filter::Source - Accepts messages coming from certain sources

=head1 SYNOPSIS

  use Log::Filter::Source;

  my $filter = new Log::Filter::Source('module_a, module_b');

  my ($result, $continue) = $filter->accept($source, $severity, $message);

=head1 DESCRIPTION

This module accepts messages, whose SOURCE value is in the given set
of acceptable values.

There are two flags, that are altering the avaluation process, see
Log::Filter::Set for details.

=head1 USAGE

=head1 BUGS

=head1 SUPPORT

=head1 AUTHOR

    Jan Mach
    Cesnet, z.s.p.o
    jan.mach@cesnet.cz
    http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Log::Filter::Set;

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION @ISA);
    $VERSION 	= '0.01';
    @ISA 		= ('Log::Filter::Set');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item _init() [PROTECTED]

  Usage     : Used from constructor as follows: return $self->_init(@_);
  Purpose   : Initialize newly created filter instance
  Returns   : $self
  Arguments : space separated string|array reference $value_set - set of acceptable values
			  string $flags - flags separated with spaces
					i - invert the result
					r - required
  Throws    : Croaks, if invoked on class or invalid arguments given
  Comments  : Internally used by parent`s new() method
  See Also  :

=cut

sub _init {
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	return $self->SUPER::_init('source', @_);
}

=pod

=back

=cut

1;
