package Log::Writer::String;
use strict;
use warnings;

#*******************************************************************************
#
# DOCUMENTATION SECTION
#
#*******************************************************************************

=head1 NAME

Log::Writer::String - STDOUT and STDERR log writer

=head1 SYNOPSIS

 use Log::Writer::String;

 my $writer = Log::Writer::String->new('ERR');
 my $writer = Log::Writer::String->new('OUT',...);
 # For more information about the constructor arguments and some more examples
 # please refer to the Log::Writer::Handle(3) manual page

 $instance->write('module', 'severity','Message from Log::Writer::String');

=head1 DESCRIPTION

This writer writes given messages to the standard output or error.

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1), Log::Writer::Handle(3), Log::Writer::Module(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
#
# INITIALIZATION AND CLEANUP SECTION
#
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #-+-> DEVEL ONLY <-+-#
#use Smart::Comments; #-+-> DEVEL ONLY <-+-#

#-- Perl CPAN modules ---------------------------------------------------------#
use IO::String;

#-- Custom application modules ------------------------------------------------#
use Log::Writer::Handle;

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL @ISA);
    $VERSION = '0.1';
    $DEVEL   = 0;
    @ISA     = ('Log::Writer::Handle');
}

#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
#
# IMPLEMENTATION SECTION
#
#*******************************************************************************

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Log::Writer::String instance
#  Arguments : SCALAR $buffer - string buffer variable
#			   (for other _init arguments see Log::Writer::Handle class)
#  Returns   : Log::Writer::Module reference
#  Throws    : Croaks, if invoked on class, or if given invalid arguments
#  See also  : Log::Writer::Handle module

sub _init
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless blessed($self);
	my ($buffer, @arguments) = @_;
	croak ((caller(0))[3] . ": expecting string buffer to be given as argument") unless defined $buffer;

	my $io_handle = IO::String->new($buffer) or die "Can't open string buffer: $!\n";
	return $self->SUPER::_init($io_handle, @arguments);
}

=pod

=back

=cut

1;
