package Package::Deb;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Package::Deb - Short module description

=head1 SYNOPSIS

 use Package::Deb;

=head1 DESCRIPTION

Extensive module description

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1), Parent::Module(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# LIBRARY LOADING SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#use Data::Dumper;                                    #--- DEVELOPMENT ONLY ---#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Package::General;

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION @ISA);
    $VERSION 	= '0.1';
    @ISA 		= ('Package::General');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub filename()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	return $self->name . '_' . $self->version . '_' . $self->arch . ".deb";
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub copy_speciffic_contents()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	print "   - Copying maintainer scripts\n";
	if (-f $self->deploy_control_dir . '/postinst')
	{
		print "     - 'postinst' file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/postinst ' . 	$self->structure('PACKAGE_CONTROL_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/postrm')
	{
		print "     - 'postrm' file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/postrm ' . 	$self->structure('PACKAGE_CONTROL_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/preinst')
	{
		print "     - 'preinst' file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/preinst ' . 	$self->structure('PACKAGE_CONTROL_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/prerm')
	{
		print "     - 'prerm' file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/prerm ' . 		$self->structure('PACKAGE_CONTROL_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/conffiles')
	{
		print "   - Copying 'conffiles' file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/conffiles ' . 	$self->structure('PACKAGE_CONTROL_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/templates')
	{
		print "   - Copying debconf templates file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/templates ' . 	$self->structure('PACKAGE_DFLT_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/config')
	{
		print "   - Copying debconf config file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/config ' . 	$self->structure('PACKAGE_DFLT_DIR')) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/init.deb')
	{
		print "   - Copying init script\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/init.deb ' . 	$self->structure('PACKAGE_INIT_DIR') . '/' . $self->service) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/default.deb')
	{
		print "   - Copying init script configuration file\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/default.deb ' . 	$self->structure('PACKAGE_DFLT_DIR') . '/' . $self->service) == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/logrotate.deb')
	{
		print "   - Copying log rotation script\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/logrotate.deb ' . 	$self->structure('PACKAGE_LOGR_DIR') . '/' . $self->service) == 0 	or die "Error executing system command: $?\n";
	}
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub generate_control_file($)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
	my ($values,) = @_;

	print " - Generating package control file\n";

	my $template_file = $self->deploy_control_dir . '/control.tmpl';
	my $control_file = $self->structure('PACKAGE_CONTROL_DIR') . '/control';

	# Load and fill the template for the vsftpd FTP daemon
	my $template = Text::Template->new(SOURCE => $template_file, UNTAINT => 1) or die "Couldn't construct template from file '$template_file': $Text::Template::ERROR\n";
    my $result = $template->fill_in(HASH => $values);

	# If the template was filled properly, store the result to the configuration file
    if (defined $result)
    {
		open (CONTROL_FILE, ">$control_file") or die "Failed to open configuration file '$control_file': $!\n";
		print CONTROL_FILE "$result\n";
		close(CONTROL_FILE);
	}
    else {
		die "Couldn't fill in template file '$template_file': $Text::Template::ERROR\n";
	}
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub generate_md5sums_file()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	print " - Generating package checksum file\n";

	my $package_dir = $self->deploy_package_dir();

	if (-d "$package_dir/etc") {
		system("/usr/bin/find $package_dir/etc -type f | /usr/bin/xargs /usr/bin/md5sum >> $package_dir/DEBIAN/md5sums.tmp") == 0 or die "Error executing system command: $?\n";
	}
	if (-d "$package_dir/etc") {
		system("/usr/bin/find $package_dir/usr -type f | /usr/bin/xargs /usr/bin/md5sum >> $package_dir/DEBIAN/md5sums.tmp") == 0 or die "Error executing system command: $?\n";
	}
	system("/bin/cat $package_dir/DEBIAN/md5sums.tmp | sed s:$package_dir/:: >> $package_dir/DEBIAN/md5sums") == 0 or die "Error executing system command: $?\n";
	system("/bin/rm -f $package_dir/DEBIAN/md5sums.tmp") == 0 or die "Error executing system command: $?\n";
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub generate_package($$$)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	print " - Generating package\n";

	my ($package_dir, $deploy_dir, $package_filename) = @_;
	system('/usr/bin/fakeroot /usr/bin/dpkg-deb --build ' . $package_dir . ' ' . "$deploy_dir/$package_filename") == 0 or die "Error executing system command: $?\n";
}

#-------------------------------------------------------------------------------

sub build()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	$self->inc_version_minor();

	$self->create_dir_structure();
	$self->copy_contents();
	$self->generate_man_pages();

	my $package_size = $self->calculate_size();
	my $control_values = { 'PACKAGE_NAME' => $self->name, 'PACKAGE_ARCH' => $self->arch, 'PACKAGE_VERSION' => $self->version, 'PACKAGE_SIZE' => $package_size };
	$self->generate_control_file($control_values);

	$self->generate_md5sums_file();
	$self->generate_package($self->deploy_package_dir, $self->deploy_dir, $self->filename);

	$self->remove_dir_structure();

	$self->_generated_true();
	print "\n- [DONE]\n";
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Package::Deb instance
#  Arguments :
#  Returns   : Package::Deb reference
#  Throws    : Croaks, if invoked on class
#  Comments  : This method must never be called directly, it is supposed to be overloaded by subclasses.
#  See Also  :

sub _init
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
	return $self;
}

# _check_sub() [PROTECTED]
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    : Croaks, if invoked on class
#  Comments  :
#  See Also  :

sub _check_sub()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
}

=pod

=back

=cut

1;
