package Package::Tar;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Package::Tar - Short module description

=head1 SYNOPSIS

 use Package::Tar;

=head1 DESCRIPTION

Extensive module description

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1), Parent::Module(3).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# LIBRARY LOADING SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#use Data::Dumper;                                    #--- DEVELOPMENT ONLY ---#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#
use Package::General;

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION @ISA);
    $VERSION 	= '0.1';
    @ISA 		= ('Package::General');
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub filename()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	return $self->name . '_' . $self->version . '_' . $self->suite . ".tar.gz";
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub filename_nover(;$)
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
	my ($tag,) = @_;
	$tag = ($tag)?$tag:'latest';

	return $self->name . '_' . $tag . '_' . $self->suite . ".tar.gz";
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub upload_via_scp($)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
	my ($destination,) = @_;
	croak ((caller(0))[3] . ": upload destination must be specified") unless $destination;

	print " - Uploading package " . $self->{PACKAGE_FILE} . " to the remote destination '$destination' via SCP\n";

	die "Package was not yet generated\n" unless $self->{PACKAGE_FILE};
	die "Package '" . $self->{PACKAGE_FILE} . "' is not ordinary file\n" unless -f $self->{PACKAGE_FILE};

	system('/usr/bin/scp ' . $self->{PACKAGE_FILE} . ' ' . $destination) == 0 or die "Error executing system command: $?\n";
	system('/usr/bin/scp ' . $self->{PACKAGE_FILE} . ' ' . $destination."/".$self->filename_nover) == 0 or die "Error executing system command: $?\n";
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub copy_speciffic_contents()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	if (-f $self->deploy_control_dir . '/init.tar')
	{
		print "   - Copying init script\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/init.tar ' . 	$self->structure('PACKAGE_SCRIPTS_DIR') . '/' . $self->service . '.init') == 0 	or die "Error executing system command: $?\n";
	}
	if (-f $self->deploy_control_dir . '/logrotate.tar')
	{
		print "   - Copying log rotation script\n";
		system('/bin/cp -R ' . $self->deploy_control_dir . '/logrotate.tar ' . 	$self->structure('PACKAGE_SCRIPTS_DIR') . '/' . $self->service . '.logrotate') == 0 	or die "Error executing system command: $?\n";
	}
}

=item [PUBLIC]

  Usage     :
  Purpose   :
  Arguments :
  Returns   :
  Throws    : Croaks, if invoked on object
  Comments  :
  See Also  :

=cut

sub generate_package($$$)
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	print " - Generating package\n";

	my ($package_dir, $deploy_dir, $package_filename) = @_;

	chdir $package_dir;
	system('/usr/bin/fakeroot /bin/tar -czf ' . "$deploy_dir/$package_filename " . "-C $package_dir *") == 0 or die "Error executing system command: $?\n";
}

#-------------------------------------------------------------------------------

sub build()
{
	my $self = shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;

	$self->create_dir_structure();
	$self->copy_contents();
	$self->generate_man_pages();

	$self->generate_package($self->deploy_package_dir, $self->deploy_dir, $self->filename);

	$self->remove_dir_structure();

	$self->_generated_true();
	print "\n- [DONE]\n";
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Package::Tar instance
#  Arguments :
#  Returns   : Package::Tar reference
#  Throws    : Croaks, if invoked on class
#  Comments  : This method must never be called directly, it is supposed to be overloaded by subclasses.
#  See Also  :

sub _init
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
	return $self;
}

# _check_sub() [PROTECTED]
#
#  Usage     :
#  Purpose   :
#  Arguments :
#  Returns   :
#  Throws    : Croaks, if invoked on class
#  Comments  :
#  See Also  :

sub _check_sub()
{
	my $self 	= shift;
	croak ((caller(0))[3] . ": instance method invoked on class") unless ref $self;
}

=pod

=back

=cut

1;
