package Tester;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Tester - Constants and utilities for testing purposes

=head1 SYNOPSIS


=head1 DESCRIPTION


=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# LIBRARY LOADING SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Getopt::Long;

#-- Perl CPAN modules ---------------------------------------------------------#
use Data::Dumper;

#-- Custom application modules ------------------------------------------------#
use Log::Loger;

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEBUG $VERBOSITY);
    $VERSION   = '0.1';
    $DEBUG     = 0;
    $VERBOSITY = 0;

    GetOptions('verbosity=i' => \$VERBOSITY, 'debug=i' => \$DEBUG);
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

sub P(@)
{
	my $dump = Dumper(@_);
	$dump =~ s/(\$VAR\d+ = )//g;
	return $dump;
}

sub P_C(@)
{
	local $Data::Dumper::Indent = 0;
	my $dump = Dumper(@_);
	$dump =~ s/(\$VAR\d+ = )//g;
	return $dump;
}

sub D(;$)
{
	my ($threshold) = @_;

	if (defined $threshold and int($threshold))
	{
		$threshold = int($threshold);
		return 1 if $DEBUG >= $threshold;
		return 0;
	}
	return 1 if $DEBUG;
	return 0;
}

sub DEBUG_ON(;$)
{
	my ($threshold) = @_;

	Log::Loger->on();

	if (defined $threshold and int($threshold))
	{
		$DEBUG = int($threshold);
	}
	else {
		$DEBUG = 1;
	}
}

sub DEBUG_OFF()
{
	$DEBUG = 0;
}

=pod

=back

=cut

1;
