package Utils::String;
use strict;
use warnings;

################################################################################
#
# DOCUMENTATION SECTION
#
################################################################################

=head1 NAME

Utils::String - String related utilities

=head1 SYNOPSIS

  use Unix::Accounts;

  my $result = trim(' 	test 	');
  my $result = ltrim(' 	test 	');
  my $result = rtrim(' 	test 	');

=head1 DESCRIPTION

This module contains string related utilities.

=head1 USAGE

=head1 BUGS

=head1 SUPPORT

=head1 AUTHOR

Jan Mach
Cesnet, z.s.p.o
jan.mach@cesnet.cz
http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.


=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

################################################################################
#
# INITIALIZATION AND CLEANUP SECTION
#
################################################################################

#-- Perl core modules ---------------------------------------------------------#
use Carp;

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#

#-- Module initializations ----------------------------------------------------#
BEGIN {
	use Exporter ();

	our ($VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);

	$VERSION = 1.00;
	@ISA = qw(Exporter);
	@EXPORT = qw(&clean &trim &ltrim &rtrim);
	%EXPORT_TAGS = (
		trim => [ qw(clean trim ltrim rtrim) ]
	);
	#@EXPORT_OK = qw($Var1 %Hashit &func3);
}

#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

################################################################################
#
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#
################################################################################

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

################################################################################
#
# IMPLEMENTATION SECTION
#
################################################################################

=item clean($)

  Usage     : my $cleaned = clean($string);
  Purpose   : Trim whitespaces from string on both ends of the string and untaint
  Returns   : string trimed string
  Arguments : string $string - string to trim
  Throws    : Nothing

=cut

sub clean($)
{
	my $string = shift;
	return $string unless defined $string;
	$string =~ s/^\s+//;
	$string =~ s/\s+$//;
	return ($string =~ m{^(.*)$})[0];
}

=item trim($)

  Usage     : my $trimed = trim($string);
  Purpose   : Trim whitespaces from string on both ends of the string
  Returns   : string trimed string
  Arguments : string $string - string to trim
  Throws    : Nothing

=cut

sub trim($)
{
	my $string = shift;
	return $string unless defined $string;
	$string =~ s/^\s+//;
	$string =~ s/\s+$//;
	return $string;
}

=item ltrim($)

  Usage     : my $trimed = ltrim($string);
  Purpose   : Trim whitespaces from the beginning of the string
  Returns   : string trimed string
  Arguments : string $string - string to trim
  Throws    : Nothing
  Comments  :
  See Also  :

=cut

sub ltrim($)
{
	my $string = shift;
	return $string unless defined $string;
	$string =~ s/^\s+//;
	return $string;
}

=item rtrim($)

  Usage     : my $trimed = rtrim($string);
  Purpose   : Trim whitespaces from the end of the string
  Returns   : string trimed string
  Arguments : string $string - string to trim
  Throws    : Nothing
  Comments  :
  See Also  :

=cut

sub rtrim($)
{
	my $string = shift;
	return $string unless defined $string;
	$string =~ s/\s+$//;
	return $string;
}

=pod

=back

=cut

1;
